﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;
using System.Linq;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;


namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfoAttribute("Move ColumnGroup right", 1, ColumnGroupState.Active, "ColumnGroup Commands", Position = 3)]
  public class MoveColumnGroupRightCommand : DataSetCommandWithAffectedColumnGroupsBase {
    [StorableConstructor]
    protected MoveColumnGroupRightCommand(bool deserializing) : base(deserializing) { }

    public MoveColumnGroupRightCommand(DataSet dataSet, List<string> affectedColumnGroups)
      : base(dataSet, affectedColumnGroups) {
    }

    public override string Description {
      get { return "Move column group right"; }
    }

    public override void Execute() {
      base.Execute();
      ColumnGroup cg = this.DataSet.GetColumnGroup(AffectedColumnGroupNames[0]);
      int columnGroupIndex = DataSet.IndexOfColumnGroup(cg);
      if (columnGroupIndex != DataSet.ColumnGroups.Count() - 1) {
        DataSet.RemoveColumnGroup(cg);
        DataSet.InsertColumnGroup(columnGroupIndex + 1, cg);
        DataSet.FireChanged();
      }
    }

    public override void UndoExecute() {
      base.UndoExecute();
      ColumnGroup cg = this.DataSet.GetColumnGroup(AffectedColumnGroupNames[0]);
      int columnGroupIndex = DataSet.IndexOfColumnGroup(cg);
      if (columnGroupIndex == 0) {
        DataSet.RemoveColumnGroup(cg);
        DataSet.InsertColumnGroup(columnGroupIndex - 1, cg);
        DataSet.FireChanged();
      }
      this.DataSet.FireChanged();
    }
  }
}